Binning Module (``taurex.binning``)
===================================

The classes here deal with binning spectra down to different resolutions.
These exist within the ``taurex.binning`` namespace


Base Module
---------------------

.. automodule:: taurex.binning.binner
   :members:
   :undoc-members:
   :show-inheritance:

Flux-Binning
---------------------------

.. automodule:: taurex.binning.fluxbinner
   :members:
   :undoc-members:
   :show-inheritance:

Simple-Binning
---------------------------

.. automodule:: taurex.binning.simplebinner
   :members:
   :undoc-members:
   :show-inheritance:

Lightcurve-Binning
---------------------------

.. automodule:: taurex.binning.lightcurvebinner
   :members:
   :undoc-members:
   :show-inheritance:

Native-Binning
---------------------------

.. automodule:: taurex.binning.nativebinner
   :members:
   :undoc-members:
   :show-inheritance:
